﻿namespace UltraTabbedMdiManagerButtons
{
    using System.Drawing;
    using Infragistics.Win;
    using Infragistics.Win.UltraWinTabs;

    internal class CF : IUIElementCreationFilter
    {
        public void AfterCreateChildElements(UIElement parent)
        {
            //  The structure of the UIElements is next:
            //  MdiTabGroupControlUIElement
            //      TabGroupUIElement - this holds a group of tabs with its scroll buttons
            //          TabScrollButtonUIElement - this holds the scroll buttons
            //              SpinScrollButtonUIElement - this is the previous button
            //              SpinScrollButtonUIElement - this is the next button
            //          TabRowUIElement - this holds all the tabs   
            //
            //  You should take the TabGroupUIElement after its child elements are created. Then
            //  you should increase the size of TabScrollButtonUIElement and decrease the width
            //  of TabRowUIElement.

            //  Get the TabGroupUIElement
            var tabGroupElement = parent as TabGroupUIElement;
            if(tabGroupElement != null)
            {
                //  Get the necessary child elements
                var tabScrollButtonElement = tabGroupElement.GetDescendant(typeof(TabScrollButtonUIElement));
                var tabRowElement = tabGroupElement.GetDescendant(typeof(TabRowUIElement));

                if(tabScrollButtonElement == null || tabRowElement == null)
                    return;

                //  Calculate the additional height you need for scroll buttons. If it is less or
                //  equal to zero simply go out of here
                var additionalHeight = tabRowElement.Rect.Height - tabScrollButtonElement.Rect.Height;
                if(additionalHeight <= 0)
                    return;

                //  As the scroll buttons are square additional width is twice the additional height
                var additionalWidth = additionalHeight * 2;

                //  Resize and reposition the scroll buttons element
                tabScrollButtonElement.Rect = new Rectangle(
                    tabScrollButtonElement.Rect.X - additionalWidth,
                    tabRowElement.Rect.Y,
                    tabScrollButtonElement.Rect.Width + additionalWidth,
                    tabScrollButtonElement.Rect.Height + additionalHeight);

                //  Resize the tab rows element
                tabRowElement.Rect = new Rectangle(
                    tabRowElement.Rect.X,
                    tabRowElement.Rect.Y,
                    tabRowElement.Rect.Width - additionalWidth,
                    tabRowElement.Rect.Height);
            }
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }
}
